/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.web.rest;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Properties;
import java.util.Set;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.core.Application;
import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

import org.osgi.framework.Constants;
import org.osgi.framework.ServiceRegistration;

/**
 * Tests the (de-)registration of applications
 */
public class ApplicationRegistrationTest extends RegistrationTestBase {

    public static class TestApplication1 extends Application {
        @Override
        public Set<Object> getSingletons() {
            return new HashSet<Object>(Arrays.asList(new TestExceptionMapper(HTTP_OK)));
        }
    }

    public static class TestApplication2 extends Application {
        @Override
        public Set<Object> getSingletons() {
            return new HashSet<Object>(Arrays.asList(new TestExceptionMapper(HTTP_FORBIDDEN)));
        }
    }

    @Provider
    public static class TestExceptionMapper implements ExceptionMapper<RuntimeException> {
        private int status;

        public TestExceptionMapper(int status) {
            this.status = status;
        }

        @Override
        public Response toResponse(RuntimeException arg0) {
            return Response.status(status).build();
        }

    }

    @Path("test")
    public static class TestResource {
        @GET
        public String handleGetRequest() {
            throw new RuntimeException("TEST EXCEPTION, IGNORE!");
        }
    }

    public void testTestRegistration() throws Exception {
        ServiceRegistration resRegistration = context.registerService(Object.class.getName(), new TestResource(), null);

        assertEquals(HTTP_INTERNAL_SERVER_ERROR, getResponseCode("test"));

        Properties props = new Properties();
        props.put(Constants.SERVICE_RANKING, 200);

        ServiceRegistration app1Registration = context.registerService(Object.class.getName(), new TestApplication1(), props);

        assertEquals(HTTP_OK, getResponseCode("test"));

        // Higher ranking means that it is chosen first...
        props = new Properties();
        props.put(Constants.SERVICE_RANKING, 1);

        ServiceRegistration app2Registration = context.registerService(Object.class.getName(), new TestApplication2(), props);

        assertEquals(HTTP_OK, getResponseCode("test"));

        app1Registration.unregister();

        assertEquals(HTTP_FORBIDDEN, getResponseCode("test"));

        app2Registration.unregister();

        assertEquals(HTTP_INTERNAL_SERVER_ERROR, getResponseCode("test"));

        resRegistration.unregister();
    }
}
